﻿Module rsesci_driver
    '= R&S ESCI EMI Test Receiver Include File =================================

    '= RSIB interface support ==================================================
    '                                                                           
    ' The RSIB interface is a R&S defined protocol for remote control of R&S    
    ' spectrum and network analyzers. In addition to the standard VISA          
    ' attributes, the RSIB passport supports the following manufacturer specific
    ' attributes:                                                               
    '                                                                           
    '***************************************************************************
    Public Const RS_ATTR_RSIB_SRE = (&H3FFC0001&)     '/* Switch a device to local or remote */
    Public Const RS_ATTR_RSIB_LOC = (&H3FFC0002&)     '/* Switch a device temporarily to local */
    Public Const RS_ATTR_RSIB_VER = (&H3FFC0003&)     '/* Passport Release Version */

    '***************************************************************************
    '= Instrument Driver Specific Error/Warning Codes ==========================
    '***************************************************************************
    Public Const VI_ERROR_INSTR_FILE_OPEN = (&H80000000& + &H3FFC0800&)
    Public Const VI_ERROR_INSTR_FILE_WRITE = (&H80000000& + &H3FFC0801&)
    Public Const VI_ERROR_INSTR_INTERPRETING_RESPONSE = (&H80000000& + &H3FFC0803&)
    Public Const VI_ERROR_INSTR_PARAMETER9 = (&H80000000& + &H3FFC0809&)
    Public Const VI_ERROR_INSTR_PARAMETER10 = (&H80000000& + &H3FFC080A&)
    Public Const VI_ERROR_INSTR_PARAMETER11 = (&H80000000& + &H3FFC080B&)
    Public Const VI_ERROR_INSTR_PARAMETER12 = (&H80000000& + &H3FFC080C&)
    Public Const VI_ERROR_INSTR_PARAMETER13 = (&H80000000& + &H3FFC080D&)
    Public Const VI_ERROR_INSTR_PARAMETER14 = (&H80000000& + &H3FFC080E&)
    Public Const VI_ERROR_INSTR_PARAMETER15 = (&H80000000& + &H3FFC080F&)

    '***************************************************************************
    '= Define Instrument Specific Error/Warning Codes Here =====================
    '***************************************************************************
    Public Const VI_WARNING_INSTR_OFFSET = (&H3FFC0900&)
    Public Const VI_ERROR_INSTR_OFFSET = (&H80000000& + &H3FFC0900&)

    Public Const RSESCI_ERROR_INSTRUMENT_ERROR = (VI_ERROR_INSTR_OFFSET + &HF0&)
    Public Const RSESCI_ERROR_INVALID_CONFIGURATION = (VI_ERROR_INSTR_OFFSET + &HF1&)
    Public Const RSESCI_ERROR_INSTRUMENT_OPTION = (VI_ERROR_INSTR_OFFSET + &HF2&)
    Public Const RSESCI_ERROR_INSTRUMENT_DATA_NOT_AVAILABLE = (VI_ERROR_INSTR_OFFSET + &HF3&)
    Public Const RSESCI_ERROR_SETTINGS_CONFLICT = (VI_ERROR_INSTR_OFFSET + &HF4&)
    Public Const RSESCI_WARNING_SMALL_BUFFER = (VI_WARNING_INSTR_OFFSET + &HF5&)
    Public Const RSESCI_ERROR_INSTRUMENT_NSUP_MODEL = (VI_ERROR_INSTR_OFFSET + &HF6&)
    Public Const RSESCI_ERROR_INSTRUMENT_IQ_OVERLOAD = (VI_ERROR_INSTR_OFFSET + &HF7&)

    '***************************************************************************
    '= Instrument specific defines =============================================
    '***************************************************************************

    ' --- Window -------------------------------------------------------------- 
    Public Const RSESCI_SCREEN_A = 1&
    Public Const RSESCI_SCREEN_B = 2&

    ' --- Step Link ----------------------------------------------------------- 
    Public Const RSESCI_FREQ_STEP_LINK_OFF = 0&
    Public Const RSESCI_FREQ_STEP_LINK_RBW = 1&
    Public Const RSESCI_FREQ_STEP_LINK_SPAN = 2&

    ' --- Frequency Mode ------------------------------------------------------ 
    Public Const RSESCI_FREQ_FIXED = 0&
    Public Const RSESCI_FREQ_SWEEP = 1&

    ' --- Axis Range Spacing -------------------------------------------------- 
    Public Const RSESCI_SPACING_LIN = 0&
    Public Const RSESCI_SPACING_LOG = 1&
    Public Const RSESCI_SPACING_LDB = 2&

    ' --- Level Axis Unit ----------------------------------------------------- 
    Public Const RSESCI_UNIT_DBM = 0&
    Public Const RSESCI_UNIT_VOLT = 1&
    Public Const RSESCI_UNIT_AMP = 2&
    Public Const RSESCI_UNIT_WATT = 3&
    Public Const RSESCI_UNIT_DBPW = 4&
    Public Const RSESCI_UNIT_DBUV = 5&
    Public Const RSESCI_UNIT_DBMV = 6&
    Public Const RSESCI_UNIT_DBUA = 7&
    Public Const RSESCI_UNIT_DBPT = 8&
    Public Const RSESCI_UNIT_DBUV_M = 9&
    Public Const RSESCI_UNIT_DBUA_M = 10&
    Public Const RSESCI_UNIT_DB = 11&

    ' --- Level Axis Scaling -------------------------------------------------- 
    Public Const RSESCI_ABS = 0&
    Public Const RSESCI_REAL = 1&

    ' --- RF Input Coupling --------------------------------------------------- 
    Public Const RSESCI_COUPLING_AC = 0&
    Public Const RSESCI_COUPLING_DC = 1&

    ' --- RF Input Impedance -------------------------------------------------- 
    Public Const RSESCI_INPUT_IMP_50 = 0&
    Public Const RSESCI_INPUT_IMP_75 = 1&

    ' --- Filter Type --------------------------------------------------------- 
    Public Const RSESCI_FILTER_NORMAL = 0&
    Public Const RSESCI_FILTER_FFT = 1&
    Public Const RSESCI_FILTER_CFIL = 2&
    Public Const RSESCI_FILTER_RRC = 3&
    Public Const RSESCI_FILTER_NOISE = 4&
    Public Const RSESCI_FILTER_PULSE = 5&

    ' --- Sweep Spacing ------------------------------------------------------- 
    Public Const RSESCI_LIN = 0&
    Public Const RSESCI_LOG = 1&
    Public Const RSESCI_AUTO = 2&

    ' --- Trigger Source ------------------------------------------------------ 
    Public Const RSESCI_TRIG_IMM = 0&
    Public Const RSESCI_TRIG_EXT = 1&
    Public Const RSESCI_TRIG_VID = 2&
    Public Const RSESCI_TRIG_IFP = 3&
    Public Const RSESCI_TRIG_RFP = 4&
    Public Const RSESCI_TRIG_TV = 5&
    Public Const RSESCI_TRIG_FM = 6&
    Public Const RSESCI_TRIG_AM = 7&
    Public Const RSESCI_TRIG_PM = 8&
    Public Const RSESCI_TRIG_AF = 9&

    ' --- Trigger Mode -------------------------------------------------------- 
    Public Const RSESCI_TRIG_LEVEL = 0&
    Public Const RSESCI_TRIG_EDGE = 1&

    ' --- Trigger Polarity ---------------------------------------------------- 
    Public Const RSESCI_POS = 0&
    Public Const RSESCI_NEG = 1&

    ' --- Field --------------------------------------------------------------- 
    Public Const RSESCI_TVFIELD_ALL = 0&
    Public Const RSESCI_TVFIELD_ODD = 1&
    Public Const RSESCI_TVFIELD_EVEN = 2&

    ' --- CCVS Signal --------------------------------------------------------- 
    Public Const RSESCI_INT = 0&
    Public Const RSESCI_EXT = 1&

    ' --- Trace Mode ---------------------------------------------------------- 
    Public Const RSESCI_TRACE_WRITE = 0&
    Public Const RSESCI_TRACE_VIEW = 1&
    Public Const RSESCI_TRACE_AVG = 2&
    Public Const RSESCI_TRACE_MAXH = 3&
    Public Const RSESCI_TRACE_MINH = 4&

    ' --- Trace Detector ------------------------------------------------------ 
    Public Const RSESCI_TRACEDET_APEAK = 0&
    Public Const RSESCI_TRACEDET_NEG = 1&
    Public Const RSESCI_TRACEDET_POS = 2&
    Public Const RSESCI_TRACEDET_SAMPLE = 3&
    Public Const RSESCI_TRACEDET_RMS = 4&
    Public Const RSESCI_TRACEDET_AVG = 5&
    Public Const RSESCI_TRACEDET_QPEAK = 6&
    Public Const RSESCI_TRACEDET_CAVG = 7&
    Public Const RSESCI_TRACEDET_CRMS = 8&

    ' --- Expression ---------------------------------------------------------- 
    Public Const RSESCI_MATH_TR1_SUB_TR2 = 0&
    Public Const RSESCI_MATH_TR1_SUB_TR3 = 1&

    ' --- Transmission Mode --------------------------------------------------- 
    Public Const RSESCI_TRANS_NEVER = 0&
    Public Const RSESCI_TRANS_ALWAYS = 1&

    ' --- Polarity ------------------------------------------------------------ 
    Public Const RSESCI_POL_POS = 0&
    Public Const RSESCI_POL_NEG = 1&

    ' --- Search Mode --------------------------------------------------------- 
    Public Const RSESCI_MARKER_PMAX = 0&
    Public Const RSESCI_MARKER_NMAX = 1&
    Public Const RSESCI_MARKER_LMAX = 2&
    Public Const RSESCI_MARKER_RMAX = 3&
    Public Const RSESCI_MARKER_PMIN = 4&
    Public Const RSESCI_MARKER_NMIN = 5&
    Public Const RSESCI_MARKER_LMIN = 6&
    Public Const RSESCI_MARKER_RMIN = 7&

    ' --- Mkr Function -------------------------------------------------------- 
    Public Const RSESCI_MARKER_TO_CENTER = 0&
    Public Const RSESCI_MARKER_TO_STEP = 1&
    Public Const RSESCI_MARKER_TO_REF = 2&

    ' --- Power Measurement --------------------------------------------------- 
    Public Const RSESCI_POWER_MEAS_AOFF = 0&
    Public Const RSESCI_POWER_MEAS_PREV = 1&
    Public Const RSESCI_POWER_MEAS_PEAK = 2&
    Public Const RSESCI_POWER_MEAS_RMS = 3&
    Public Const RSESCI_POWER_MEAS_MEAN = 4&
    Public Const RSESCI_POWER_MEAS_SDEV = 5&

    ' --- Result Type --------------------------------------------------------- 
    Public Const RSESCI_RESULT_CURR = 0&
    Public Const RSESCI_RESULT_AVG = 1&
    Public Const RSESCI_RESULT_PHOLD = 2&

    ' --- Measurement --------------------------------------------------------- 
    Public Const RSESCI_FDOMAIN_MEAS_OFF = 0&
    Public Const RSESCI_FDOMAIN_MEAS_CPOW = 1&
    Public Const RSESCI_FDOMAIN_MEAS_ACP = 2&
    Public Const RSESCI_FDOMAIN_MEAS_MCAC = 3&
    Public Const RSESCI_FDOMAIN_MEAS_OBW = 4&
    Public Const RSESCI_FDOMAIN_MEAS_CN = 5&
    Public Const RSESCI_FDOMAIN_MEAS_CN0 = 6&

    ' --- Standard ------------------------------------------------------------ 
    Public Const RSESCI_STANDARD_NONE = 0&
    Public Const RSESCI_STANDARD_NADC = 1&
    Public Const RSESCI_STANDARD_TETRA = 2&
    Public Const RSESCI_STANDARD_PDC = 3&
    Public Const RSESCI_STANDARD_PHS = 4&
    Public Const RSESCI_STANDARD_CDPD = 5&
    Public Const RSESCI_STANDARD_FWCD = 6&
    Public Const RSESCI_STANDARD_RWCD = 7&
    Public Const RSESCI_STANDARD_F8CD = 8&
    Public Const RSESCI_STANDARD_R8CD = 9&
    Public Const RSESCI_STANDARD_F19C = 10&
    Public Const RSESCI_STANDARD_R19C = 11&
    Public Const RSESCI_STANDARD_FW3G = 12&
    Public Const RSESCI_STANDARD_RW3G = 13&
    Public Const RSESCI_STANDARD_D2CD = 14&
    Public Const RSESCI_STANDARD_S2CD = 15&
    Public Const RSESCI_STANDARD_M2CD = 16&
    Public Const RSESCI_STANDARD_FIS95C0 = 17&
    Public Const RSESCI_STANDARD_RIS95C0 = 18&
    Public Const RSESCI_STANDARD_FIS95C1 = 19&
    Public Const RSESCI_STANDARD_RIS95C1 = 20&
    Public Const RSESCI_STANDARD_TCDM = 21&

    ' --- Size ---------------------------------------------------------------- 
    Public Const RSESCI_WINDOW_SMALL = 0&
    Public Const RSESCI_WINDOW_LARGE = 1&

    ' --- Channel Bandwidth --------------------------------------------------- 
    Public Const RSESCI_BWID_TX = 0&
    Public Const RSESCI_BWID_ADJ = 1&
    Public Const RSESCI_BWID_ALT1 = 2&
    Public Const RSESCI_BWID_ALT2 = 3&

    ' --- ACP Reference Channel ----------------------------------------------- 
    Public Const RSESCI_ACP_REFERENCE_TX1 = 0&
    Public Const RSESCI_ACP_REFERENCE_TX2 = 1&
    Public Const RSESCI_ACP_REFERENCE_TX3 = 2&
    Public Const RSESCI_ACP_REFERENCE_TX4 = 3&
    Public Const RSESCI_ACP_REFERENCE_MIN = 4&
    Public Const RSESCI_ACP_REFERENCE_MAX = 5&
    Public Const RSESCI_ACP_REFERENCE_LOW_HIGH = 6&

    ' --- Measurement --------------------------------------------------------- 
    Public Const RSESCI_STAT_AOFF = 0&
    Public Const RSESCI_STAT_APD = 1&
    Public Const RSESCI_STAT_CCDF = 2&

    ' --- Result Type --------------------------------------------------------- 
    Public Const RSESCI_STAT_RESULT_ALL = 0&
    Public Const RSESCI_STAT_RESULT_MEAN = 1&
    Public Const RSESCI_STAT_RESULT_PEAK = 2&
    Public Const RSESCI_STAT_RESULT_CFAC = 3&

    ' --- Scan Mode ----------------------------------------------------------- 
    Public Const RSESCI_SCAN_CONT = 1&
    Public Const RSESCI_SCAN_SING = 0&

    ' --- Final Detector ------------------------------------------------------ 
    Public Const RSESCI_DETECTOR_MAXP = 0&
    Public Const RSESCI_DETECTOR_MINP = 1&
    Public Const RSESCI_DETECTOR_RMS = 2&
    Public Const RSESCI_DETECTOR_AVG = 3&
    Public Const RSESCI_DETECTOR_QPEAK = 4&
    Public Const RSESCI_DETECTOR_CAV = 5&

    ' --- Search Method ------------------------------------------------------- 
    Public Const RSESCI_SEARCH_SUBR = 0&
    Public Const RSESCI_SEARCH_PEAK = 1&

    ' --- Indication ---------------------------------------------------------- 
    Public Const RSESCI_SYMBOL_OFF = 0&
    Public Const RSESCI_SYMBOL_CROSS = 1&

    ' --- Measurement --------------------------------------------------------- 
    Public Const RSESCI_VNET_MEAS_FINAL = 1&
    Public Const RSESCI_VNET_MEAS_PRESCAN = 0&

    ' --- Protective Earth ---------------------------------------------------- 
    Public Const RSESCI_EARTH_GROUNDED = 0&
    Public Const RSESCI_EARTH_FLOATING = 1&

    ' --- Phase --------------------------------------------------------------- 
    Public Const RSESCI_PHASE_N = 0&
    Public Const RSESCI_PHASE_L1 = 1&
    Public Const RSESCI_PHASE_L2 = 2&
    Public Const RSESCI_PHASE_L3 = 3&

    ' --- Demodulation -------------------------------------------------------- 
    Public Const RSESCI_DEMOD_OFF = 0&
    Public Const RSESCI_DEMOD_AM = 1&
    Public Const RSESCI_DEMOD_FM = 2&

    ' --- Peak List Sort Mode ------------------------------------------------- 
    Public Const RSESCI_X = 0&
    Public Const RSESCI_Y = 1&

    ' --- Calibration Source  ------------------------------------------------- 
    Public Const RSESCI_RF_INPUT = 0&
    Public Const RSESCI_INT_CALIB_SOURCE = 1&

    ' --- Clear --------------------------------------------------------------- 
    Public Const RSESCI_CLEAR_ALL = 0&
    Public Const RSESCI_CLEAR_FILE = 1&

    ' --- File Operations ----------------------------------------------------- 
    Public Const RSESCI_FILE_MAN_CDRIVE = 0&
    Public Const RSESCI_FILE_MAN_CDIR = 1&
    Public Const RSESCI_FILE_MAN_MDIR = 2&
    Public Const RSESCI_FILE_MAN_RDIR = 3&
    Public Const RSESCI_FILE_MAN_COPY = 4&
    Public Const RSESCI_FILE_MAN_MOVE = 5&
    Public Const RSESCI_FILE_MAN_DELETE = 6&
    Public Const RSESCI_FILE_MAN_FORMAT = 7&

    ' --- Instrument Mode ----------------------------------------------------- 
    Public Const RSESCI_INSTRUMENT_MODE_SANALYZER = 0&
    Public Const RSESCI_INSTRUMENT_MODE_RECEIVER = 1&
    Public Const RSESCI_INSTRUMENT_MODE_ADEMOD = 2&

    ' --- V-network Type ------------------------------------------------------ 
    Public Const RSESCI_VNET_OFF = 0&
    Public Const RSESCI_VNET_TWO = 1&
    Public Const RSESCI_VNET_FOUR = 2&

    ' --- Interface Type ------------------------------------------------------ 
    Public Const RSESCI_INTF_GPIB = 0&
    Public Const RSESCI_INTF_TTL = 1&

    ' --- Screen Mode --------------------------------------------------------- 
    Public Const RSESCI_SCREEN_SINGLE = 0&
    Public Const RSESCI_SCREEN_SPLIT = 1&

    ' --- Coupling Mode ------------------------------------------------------- 
    Public Const RSESCI_INST_COUP_NONE = 0&
    Public Const RSESCI_INST_COUP_RLEVEL = 1&
    Public Const RSESCI_INST_COUP_CF_A = 2&
    Public Const RSESCI_INST_COUP_CF_B = 3&

    ' --- Sweep Mode ---------------------------------------------------------- 
    Public Const RSESCI_SINGLE_SWEEP = 0&
    Public Const RSESCI_CONTINUOUS_SWEEP = 1&

    ' --- Destination --------------------------------------------------------- 
    Public Const RSESCI_HARDCOPY_DISK = 0&
    Public Const RSESCI_HARDCOPY_PRINTER = 1&
    Public Const RSESCI_HARDCOPY_CLIPBOARD = 2&

    ' --- Data Format --------------------------------------------------------- 
    Public Const RSESCI_HARDCOPY_WMF = 0&
    Public Const RSESCI_HARDCOPY_GDI = 1&
    Public Const RSESCI_HARDCOPY_EWMF = 2&
    Public Const RSESCI_HARDCOPY_BMP = 3&

    ' --- Page Orientation ---------------------------------------------------- 
    Public Const RSESCI_HARDCOPY_PORTRAIT = 0&
    Public Const RSESCI_HARDCOPY_LANDSCAPE = 1&

    ' --- Hardcopy Items ------------------------------------------------------ 
    Public Const RSESCI_HARDCOPY_ALL = 0&
    Public Const RSESCI_HARDCOPY_TABLE = 1&
    Public Const RSESCI_HARDCOPY_TRACE = 2&

    ' --- Color Map ----------------------------------------------------------- 
    Public Const RSESCI_CMAP_1 = 1&
    Public Const RSESCI_CMAP_2 = 2&
    Public Const RSESCI_CMAP_3 = 3&
    Public Const RSESCI_CMAP_4 = 4&
    Public Const RSESCI_CMAP_5 = 5&
    Public Const RSESCI_CMAP_6 = 6&
    Public Const RSESCI_CMAP_7 = 7&
    Public Const RSESCI_CMAP_8 = 8&
    Public Const RSESCI_CMAP_9 = 9&
    Public Const RSESCI_CMAP_10 = 10&
    Public Const RSESCI_CMAP_11 = 11&
    Public Const RSESCI_CMAP_12 = 12&
    Public Const RSESCI_CMAP_13 = 13&
    Public Const RSESCI_CMAP_14 = 14&
    Public Const RSESCI_CMAP_15 = 15&
    Public Const RSESCI_CMAP_16 = 16&
    Public Const RSESCI_CMAP_17 = 17&
    Public Const RSESCI_CMAP_18 = 18&
    Public Const RSESCI_CMAP_19 = 19&
    Public Const RSESCI_CMAP_20 = 20&
    Public Const RSESCI_CMAP_21 = 21&
    Public Const RSESCI_CMAP_22 = 22&
    Public Const RSESCI_CMAP_23 = 23&
    Public Const RSESCI_CMAP_24 = 24&
    Public Const RSESCI_CMAP_25 = 25&
    Public Const RSESCI_CMAP_26 = 26&
    Public Const RSESCI_CMAP_27 = 27&
    Public Const RSESCI_CMAP_28 = 28&
    Public Const RSESCI_CMAP_29 = 29&
    Public Const RSESCI_CMAP_30 = 30&
    Public Const RSESCI_CMAP_31 = 31&
    Public Const RSESCI_CMAP_32 = 32&
    Public Const RSESCI_CMAP_33 = 33&

    ' --- Predefined Colors --------------------------------------------------- 
    Public Const RSESCI_USER_DEFINED = -1&
    Public Const RSESCI_BLACK = 0&
    Public Const RSESCI_BLUE = 1&
    Public Const RSESCI_BROWN = 2&
    Public Const RSESCI_GREEN = 3&
    Public Const RSESCI_CYAN = 4&
    Public Const RSESCI_RED = 5&
    Public Const RSESCI_MAGNETA = 6&
    Public Const RSESCI_YELLOW = 7&
    Public Const RSESCI_WHITE = 8&
    Public Const RSESCI_DGRAY = 9&
    Public Const RSESCI_LGRAY = 10&
    Public Const RSESCI_LBLUE = 11&
    Public Const RSESCI_LGREEN = 12&
    Public Const RSESCI_LCYAN = 13&
    Public Const RSESCI_LRED = 14&
    Public Const RSESCI_LMAGNETA = 15&

    ' --- Predefined Colors --------------------------------------------------- 
    Public Const RSESCI_DEFAULT_USER_DEFINED = 0&
    Public Const RSESCI_DEFAULT_COLOR_SET = 1&
    Public Const RSESCI_DEFAULT_SCREEN_COLORS = 2&

    ' --- Default Colors ------------------------------------------------------ 
    Public Const RSESCI_DEFAULT_1 = 1&
    Public Const RSESCI_DEFAULT_2 = 2&

    ' --- Result Display ------------------------------------------------------ 
    Public Const RSESCI_FM_SUMMARY = 0&
    Public Const RSESCI_DEMOD_FM_SIG = 1&
    Public Const RSESCI_AFS_FM_SIG = 2&
    Public Const RSESCI_RFS_FM_SIG = 3&
    Public Const RSESCI_PM_SUMMARY = 4&
    Public Const RSESCI_DEMOD_PM_SIG = 5&
    Public Const RSESCI_AFS_PM_SIG = 6&
    Public Const RSESCI_AM_SUMMARY = 7&
    Public Const RSESCI_DEMOD_AM_SIG = 8&
    Public Const RSESCI_AFS_AM_SIG = 9&
    Public Const RSESCI_RFP_AM_SIG = 10&

    ' --- Display Size -------------------------------------------------------- 
    Public Const RSESCI_SCREEN_SMALL = 0&
    Public Const RSESCI_SCREEN_LARGE = 1&

    ' --- Averaging Type ------------------------------------------------------ 
    Public Const RSESCI_AVERAGE_LINEAR = 0&
    Public Const RSESCI_AVERAGE_VIDEO = 1&

    ' --- Angle Units --------------------------------------------------------- 
    Public Const RSESCI_ANGLE_UNITS_RAD = 0&
    Public Const RSESCI_ANGLE_UNITS_DEG = 1&

    ' --- Modulation Measurement ---------------------------------------------- 
    Public Const RSESCI_MOD_MEAS_PPEAK = 0&
    Public Const RSESCI_MOD_MEAS_MPEAK = 1&
    Public Const RSESCI_MOD_MEAS_MIDDLE = 2&
    Public Const RSESCI_MOD_MEAS_RMS = 3&

    ' --- Demodulation Type --------------------------------------------------- 
    Public Const RSESCI_DEMOD_TYPE_AM = 0&
    Public Const RSESCI_DEMOD_TYPE_FM = 1&
    Public Const RSESCI_DEMOD_TYPE_PM = 2&

    ' --- Measurement Type ---------------------------------------------------- 
    Public Const RSESCI_MEASUREMENT_IMM = 0&
    Public Const RSESCI_MEASUREMENT_AVERAGE = 1&

    ' --- Tracking Generator Measurement -------------------------------------- 
    Public Const RSESCI_CORRECTION_TRAN = 0&
    Public Const RSESCI_CORRECTION_REFL = 1&

    ' --- Tracking Generator Calibration -------------------------------------- 
    Public Const RSESCI_ACQ_THR = 0&
    Public Const RSESCI_ACQ_OPEN = 1&

    ' ---  Limit Line --------------------------------------------------------- 
    Public Const RSESCI_LIMIT_LOWER = 0&
    Public Const RSESCI_LIMIT_UPPER = 1&

    ' --- Domain -------------------------------------------------------------- 
    Public Const RSESCI_DOMAIN_FREQ = 0&
    Public Const RSESCI_DOMAIN_TIME = 1&

    ' --- Limit --------------------------------------------------------------- 
    Public Const RSESCI_LIMIT_X = 2&

    ' --- Parity -------------------------------------------------------------- 
    Public Const RSESCI_NONE = 0&
    Public Const RSESCI_EVEN = 1&
    Public Const RSESCI_ODD = 2&

    ' --- Port Type ----------------------------------------------------------- 
    Public Const RSESCI_INPUT = 0&
    Public Const RSESCI_OUTPUT = 1&

    ' --- Data Set Items ------------------------------------------------------ 
    Public Const RSESCI_DATA_SET_NONE = 0&
    Public Const RSESCI_DATA_SET_DEFAULT = 1&
    Public Const RSESCI_DATA_SET_ALL = 2&
    Public Const RSESCI_DATA_SET_CURRENT = 3&
    Public Const RSESCI_DATA_SET_TRACES = 4&
    Public Const RSESCI_DATA_SET_FINAL_LIST = 5&
    Public Const RSESCI_DATA_SET_LIMIT_LINES = 6&
    Public Const RSESCI_DATA_SET_CALIBRATION = 7&
    Public Const RSESCI_DATA_SET_TRANSDUCERS = 8&

    ' --- Decimal Point Notation ---------------------------------------------- 
    Public Const RSESCI_DEC_SEPARATOR_POINT = 0&
    Public Const RSESCI_DEC_SEPARATOR_COMMA = 1&

    ' --- Mixed Instrument Mode ----------------------------------------------- 
    Public Const RSESCI_MIXED_MODE_DISPLAY_SANALYZER = 0&
    Public Const RSESCI_MIXED_MODE_DISPLAY_RECEIVER = 1&

    ' --- Result Type --------------------------------------------------------- 
    Public Const RSESCI_RESULT_TYPE_OFF = 0&
    Public Const RSESCI_RESULT_TYPE_WRITE = 1&
    Public Const RSESCI_RESULT_TYPE_AVERAGE = 2&
    Public Const RSESCI_RESULT_TYPE_MAXHOLD = 3&
    Public Const RSESCI_RESULT_TYPE_MINHOLD = 4&
    Public Const RSESCI_RESULT_TYPE_VIEW = 5&

    '***************************************************************************
    '= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======
    '***************************************************************************

    Declare Function rsesci_init Lib "rsesci_32.dll" (ByVal resourceName As String, ByVal IDQuery As Integer, ByVal resetDevice As Integer, ByRef instrSession As Integer) As Integer
    Declare Function rsesci_ReadSpectrum Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal measurementMode As Int32, ByVal frequencyParameter As Int32, ByVal startFrequency As Double, ByVal stopFrequency As Double, ByRef samplesReturned As Int32, ByRef traceData As Double) As Integer
    Declare Function rsesci_SetCenterFrequency Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal centerFrequency As Double) As Integer
    Declare Function rsesci_GetCenterFrequency Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef centerFrequency As Double) As Integer
    Declare Function rsesci_SetStartFrequency Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal startFrequency As Double) As Integer
    Declare Function rsesci_GetStartFrequency Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef startFrequency As Double) As Integer
    Declare Function rsesci_SetStopFrequency Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal stopFrequency As Double) As Integer
    Declare Function rsesci_GetStopFrequency Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef stopFrequency As Double) As Integer
    Declare Function rsesci_SetFrequencyOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal frequencyOffset As Double) As Integer
    Declare Function rsesci_GetFrequencyOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef frequencyOffset As Double) As Integer
    Declare Function rsesci_SetFrequencyMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal frequencyMode As Int32) As Integer
    Declare Function rsesci_GetFrequencyMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef frequencyMode As Int32) As Integer
    Declare Function rsesci_SetCenterFrequencyStepWidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal stepWidth As Double) As Integer
    Declare Function rsesci_GetCenterFrequencyStepWidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef stepWidth As Double) As Integer
    Declare Function rsesci_SetCenterFrequencyStepLink Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal stepLink As Int32) As Integer
    Declare Function rsesci_GetCenterFrequencyStepLink Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef stepLink As Int32) As Integer
    Declare Function rsesci_SetCenterFrequencyStepLinkFactor Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal stepLinkFactor As Int32) As Integer
    Declare Function rsesci_GetCenterFrequencyStepLinkFactor Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef stepLinkFactor As Int32) As Integer
    Declare Function rsesci_SetSignalTracking Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal signalTracking As Integer) As Integer
    Declare Function rsesci_GetSignalTracking Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef signalTracking As Integer) As Integer
    Declare Function rsesci_SetSignalTrackingBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal signalTrackingBandwidth As Double) As Integer
    Declare Function rsesci_GetSignalTrackingBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef signalTrackingBandwidth As Double) As Integer
    Declare Function rsesci_SetSignalTrackingThreshold Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal signalTrackingThreshold As Double) As Integer
    Declare Function rsesci_GetSignalTrackingThreshold Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef signalTrackingThreshold As Double) As Integer
    Declare Function rsesci_SetSignalTrackingTrace Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal signalTrackingTrace As Int32) As Integer
    Declare Function rsesci_GetSignalTrackingTrace Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef signalTrackingTrace As Int32) As Integer
    Declare Function rsesci_SetFrequencySpan Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal frequencySpan As Double) As Integer
    Declare Function rsesci_GetFrequencySpan Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef frequencySpan As Double) As Integer
    Declare Function rsesci_SetReferenceLevel Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal referenceLevel As Double) As Integer
    Declare Function rsesci_GetReferenceLevel Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef referenceLevel As Double) As Integer
    Declare Function rsesci_SetReferenceLevelOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal referenceLevelOffset As Double) As Integer
    Declare Function rsesci_GetReferenceLevelOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef referenceLevelOffset As Double) As Integer
    Declare Function rsesci_SetReferenceLevelPosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal referenceLevelPosition As Double) As Integer
    Declare Function rsesci_GetReferenceLevelPosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef referenceLevelPosition As Double) As Integer
    Declare Function rsesci_SetReferenceLevelPositionValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal referenceLevelPosition As Double) As Integer
    Declare Function rsesci_GetReferenceLevelPositionValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef referenceLevelPosition As Double) As Integer
    Declare Function rsesci_SetLevelAxisRange Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal levelAxisRange As Double) As Integer
    Declare Function rsesci_GetLevelAxisRange Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef levelAxisRange As Double) As Integer
    Declare Function rsesci_SetLevelAxisMinimum Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal levelAxisMinimum As Double) As Integer
    Declare Function rsesci_GetLevelAxisMinimum Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef levelAxisMinimum As Double) As Integer
    Declare Function rsesci_SetLevelAxisRangeSpacing Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal levelAxisRangeSpacing As Int32) As Integer
    Declare Function rsesci_GetLevelAxisRangeSpacing Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef levelAxisRangeSpacing As Int32) As Integer
    Declare Function rsesci_SetLevelAxisUnit Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal levelAxisUnit As Int32) As Integer
    Declare Function rsesci_GetLevelAxisUnit Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef levelAxisUnit As Int32) As Integer
    Declare Function rsesci_SetLevelAxisScaling Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal levelAxisScaling As Int32) As Integer
    Declare Function rsesci_GetLevelAxisScaling Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef levelAxisScaling As Int32) As Integer
    Declare Function rsesci_SetRFInputCoupling Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal RFInputCoupling As Int32) As Integer
    Declare Function rsesci_GetRFInputCoupling Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef RFInputCoupling As Int32) As Integer
    Declare Function rsesci_SetRFInputAttenuation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal attenuation As Double) As Integer
    Declare Function rsesci_GetRFInputAttenuation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef attenuation As Double) As Integer
    Declare Function rsesci_SetRFInputAttenuationAuto Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal attenuationAuto As Integer) As Integer
    Declare Function rsesci_GetRFInputAttenuationAuto Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef attenuationAuto As Integer) As Integer
    Declare Function rsesci_SetRFInputAttenuationProtection Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal attenuationProtection As Integer) As Integer
    Declare Function rsesci_GetRFInputAttenuationProtection Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef attenuationProtection As Integer) As Integer
    Declare Function rsesci_SetRFInputImpedance Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal RFInputImpedance As Int32) As Integer
    Declare Function rsesci_GetRFInputImpedance Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef RFInputImpedance As Int32) As Integer
    Declare Function rsesci_SetPreamplifierAuto Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal preamplifierAuto As Integer) As Integer
    Declare Function rsesci_GetPreamplifierAuto Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef preamplifierAuto As Integer) As Integer
    Declare Function rsesci_SetPreamplifier Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal preamplifier As Integer) As Integer
    Declare Function rsesci_GetPreamplifier Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef preamplifier As Integer) As Integer
    Declare Function rsesci_SetResolutionBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal resolutionBandwidth As Double) As Integer
    Declare Function rsesci_GetResolutionBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef resolutionBandwidth As Double) As Integer
    Declare Function rsesci_SetResolutionBandwidthAuto Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal autoResolutionBandwidth As Integer) As Integer
    Declare Function rsesci_GetResolutionBandwidthAuto Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef autoResolutionBandwidth As Integer) As Integer
    Declare Function rsesci_SetResolutionBandwidthCouplingRatio Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal ratio As Double) As Integer
    Declare Function rsesci_GetResolutionBandwidthCouplingRatio Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef ratio As Double) As Integer
    Declare Function rsesci_SetResolutionBandwidthFilterType Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal filterType As Int32) As Integer
    Declare Function rsesci_GetResolutionBandwidthFilterType Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef filterType As Int32) As Integer
    Declare Function rsesci_SetVideoBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal videoBandwidth As Double) As Integer
    Declare Function rsesci_GetVideoBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef videoBandwidth As Double) As Integer
    Declare Function rsesci_SetVideoBandwidthAuto Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal autoVideoBandwidth As Integer) As Integer
    Declare Function rsesci_GetVideoBandwidthAuto Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef autoVideoBandwidth As Integer) As Integer
    Declare Function rsesci_SetVideoBandwidthCouplingRatio Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal ratio As Double) As Integer
    Declare Function rsesci_GetVideoBandwidthCouplingRatio Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef ratio As Double) As Integer
    Declare Function rsesci_SetVideoBandwidthMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal bandwidthMode As Int32) As Integer
    Declare Function rsesci_GetVideoBandwidthMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef bandwidthMode As Int32) As Integer
    Declare Function rsesci_ContinueSingleSweep Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32) As Integer
    Declare Function rsesci_GetNumberStartedSweeps Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef startedScans As Int32) As Integer
    Declare Function rsesci_SetSweepMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal continuousSweep As Int32) As Integer
    Declare Function rsesci_GetSweepMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef continuousSweep As Int32) As Integer
    Declare Function rsesci_SetSweepTime Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal sweepTime As Double) As Integer
    Declare Function rsesci_GetSweepTime Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef sweepTime As Double) As Integer
    Declare Function rsesci_SetSweepTimeAuto Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal autoSweepTime As Integer) As Integer
    Declare Function rsesci_GetSweepTimeAuto Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef autoSweepTime As Integer) As Integer
    Declare Function rsesci_SetSweepCount Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal sweepCount As Int32) As Integer
    Declare Function rsesci_GetSweepCount Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef sweepCount As Int32) As Integer
    Declare Function rsesci_SetSweepPoints Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal sweepPoints As Int32) As Integer
    Declare Function rsesci_GetSweepPoints Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef sweepPoints As Int32) As Integer
    Declare Function rsesci_SetSingleSweepDisplay Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal displayState As Integer) As Integer
    Declare Function rsesci_GetSingleSweepDisplay Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef displayState As Integer) As Integer
    Declare Function rsesci_SetSweepSpacing Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal sweepSpacing As Int32) As Integer
    Declare Function rsesci_GetSweepSpacing Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef sweepSpacing As Int32) As Integer
    Declare Function rsesci_Abort Lib "rsesci_32.dll" (ByVal instrSession As Integer) As Integer
    Declare Function rsesci_Hold Lib "rsesci_32.dll" (ByVal instrSession As Integer) As Integer
    Declare Function rsesci_SendTrigger Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32) As Integer
    Declare Function rsesci_SendTriggerWaitOPC Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_timeout As Int32) As Integer
    Declare Function rsesci_SetTriggerSource Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal triggerSource As Int32) As Integer
    Declare Function rsesci_GetTriggerSource Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef triggerSource As Int32) As Integer
    Declare Function rsesci_SetTriggerLevel Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal signalType As Int32, ByVal triggerLevel As Double) As Integer
    Declare Function rsesci_GetTriggerLevel Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal signalType As Int32, ByRef triggerLevel As Double) As Integer
    Declare Function rsesci_SetTriggerOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal triggerDelay As Double) As Integer
    Declare Function rsesci_GetTriggerOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef triggerDelay As Double) As Integer
    Declare Function rsesci_SetTriggerSourcePolarity Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal polarity As Int32) As Integer
    Declare Function rsesci_GetTriggerSourcePolarity Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef polarity As Int32) As Integer
    Declare Function rsesci_SetGatedTrigger Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal gatedTrigger As Integer) As Integer
    Declare Function rsesci_GetGatedTrigger Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef gatedTrigger As Integer) As Integer
    Declare Function rsesci_SetGatedTriggerSource Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal triggerSource As Int32) As Integer
    Declare Function rsesci_GetGatedTriggerSource Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef triggerSource As Int32) As Integer
    Declare Function rsesci_SetGatedTriggerMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal triggerMode As Int32) As Integer
    Declare Function rsesci_GetGatedTriggerMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef triggerMode As Int32) As Integer
    Declare Function rsesci_SetGatedTriggerPolarity Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal triggerPolarity As Int32) As Integer
    Declare Function rsesci_GetGatedTriggerPolarity Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef triggerPolarity As Int32) As Integer
    Declare Function rsesci_SetGatedTriggerDelay Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal triggerDelay As Double) As Integer
    Declare Function rsesci_GetGatedTriggerDelay Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef triggerDelay As Double) As Integer
    Declare Function rsesci_SetGatedTriggerLength Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal triggerLength As Double) As Integer
    Declare Function rsesci_GetGatedTriggerLength Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef triggerLength As Double) As Integer
    Declare Function rsesci_SetTVTrigger Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal TVTrigger As Integer) As Integer
    Declare Function rsesci_GetTVTrigger Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef TVTrigger As Integer) As Integer
    Declare Function rsesci_SetTVTriggerVerticalSync Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal field As Int32) As Integer
    Declare Function rsesci_GetTVTriggerVerticalSync Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef field As Int32) As Integer
    Declare Function rsesci_SetTVTriggerHorizontalSync Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal lineNumber As Int32) As Integer
    Declare Function rsesci_GetTVTriggerHorizontalSync Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef lineNumber As Int32) As Integer
    Declare Function rsesci_SetTVTriggerPolarity Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal polarity As Int32) As Integer
    Declare Function rsesci_GetTVTriggerPolarity Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef polarity As Int32) As Integer
    Declare Function rsesci_SetTVTriggerLines Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal linesSystem As Int32) As Integer
    Declare Function rsesci_GetTVTriggerLines Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef linesSystem As Int32) As Integer
    Declare Function rsesci_SetTVTriggerCCVS Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal CCVSSignal As Int32) As Integer
    Declare Function rsesci_GetTVTriggerCCVS Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef CCVSSignal As Int32) As Integer
    Declare Function rsesci_SetTraceMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32, ByVal traceMode As Int32) As Integer
    Declare Function rsesci_GetTraceMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32, ByRef traceMode As Int32) As Integer
    Declare Function rsesci_SetTraceBlanking Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32, ByVal traceState As Integer) As Integer
    Declare Function rsesci_GetTraceBlanking Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32, ByRef traceState As Integer) As Integer
    Declare Function rsesci_SetTraceDetector Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32, ByVal traceDetector As Int32) As Integer
    Declare Function rsesci_GetTraceDetector Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32, ByRef traceDetector As Int32) As Integer
    Declare Function rsesci_SetTraceDetectorAuto Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32, ByVal coupleDetector As Integer) As Integer
    Declare Function rsesci_GetTraceDetectorAuto Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32, ByRef coupleDetector As Integer) As Integer
    Declare Function rsesci_SetTraceMath Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal mathRelation As Integer) As Integer
    Declare Function rsesci_GetTraceMath Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef mathRelation As Integer) As Integer
    Declare Function rsesci_SetTraceMathMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal mathMode As Int32) As Integer
    Declare Function rsesci_GetTraceMathMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef mathMode As Int32) As Integer
    Declare Function rsesci_SetTraceMathPosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal position As Double) As Integer
    Declare Function rsesci_GetTraceMathPosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef position As Double) As Integer
    Declare Function rsesci_SetTraceMathExpression Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal expression As Int32) As Integer
    Declare Function rsesci_GetTraceMathExpression Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef expression As Int32) As Integer
    Declare Function rsesci_SetTraceFeedControl Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal x_control As Int32, ByVal transmissionMode As Int32) As Integer
    Declare Function rsesci_GetTraceFeedControl Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal x_control As Int32, ByRef transmissionMode As Int32) As Integer
    Declare Function rsesci_SetIQTrace Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal IQTraceState As Integer) As Integer
    Declare Function rsesci_GetIQTrace Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef IQTraceState As Integer) As Integer
    Declare Function rsesci_SetIQTraceAveraging Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal IQTraceState As Integer) As Integer
    Declare Function rsesci_GetIQTraceAveraging Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef IQTraceState As Integer) As Integer
    Declare Function rsesci_SetIQTraceAveragingCount Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal averageCount As Int32) As Integer
    Declare Function rsesci_GetIQTraceAveragingCount Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef averageCount As Int32) As Integer
    Declare Function rsesci_SetIQTraceSynchronization Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_state As Integer) As Integer
    Declare Function rsesci_GetIQTraceSynchronization Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef x_state As Integer) As Integer
    Declare Function rsesci_SetIQTraceSamplingRate Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal samplingRate As Double) As Integer
    Declare Function rsesci_GetIQTraceSamplingRate Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef samplingRate As Double) As Integer
    Declare Function rsesci_SetIQTraceSettings Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal samplingRate As Double, ByVal triggerMode As Int32, ByVal polarity As Int32, ByVal bandwidth As Double, ByVal pretriggerSamples As Int32, ByVal no_ofSamples As Int32) As Integer
    Declare Function rsesci_GetIQTraceSettings Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef samplingRate As Double, ByRef triggerMode As Int32, ByRef polarity As Int32, ByRef bandwidth As Double, ByRef pretriggerSamples As Int32, ByRef no_ofSamples As Int32) As Integer
    Declare Function rsesci_CopyTrace Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal sourceTrace As Int32, ByVal destinationTrace As Int32) As Integer
    Declare Function rsesci_ReadTraceData Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32, ByRef no_ofPoints As Int32, ByRef traceData As Double) As Integer
    Declare Function rsesci_WriteTraceData Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32, ByVal no_ofPoints As Int32, ByRef traceData As Double) As Integer
    Declare Function rsesci_ReadIQTraceData Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal bufferSize As Int32, ByRef no_ofPoints As Int32, ByRef realParts_I As Double, ByRef imaginaryParts_Q As Double) As Integer
    Declare Function rsesci_ReadIQTraceDataMemory Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal offsetSamples As Int32, ByVal no_ofSamples As Int32, ByVal bufferSize As Int32, ByRef no_ofPoints As Int32, ByRef realParts_I As Double, ByRef imaginaryParts_Q As Double) As Integer
    Declare Function rsesci_CalibrationTotal Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef result As Int32) As Integer
    Declare Function rsesci_CalibrationAbort Lib "rsesci_32.dll" (ByVal instrSession As Integer) As Integer
    Declare Function rsesci_CalibrationResults Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal calibrationResult As String) As Integer
    Declare Function rsesci_SetCalibrationCorrection Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal calibrationState As Integer) As Integer
    Declare Function rsesci_GetCalibrationCorrection Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef calibrationState As Integer) As Integer
    Declare Function rsesci_RunScan Lib "rsesci_32.dll" (ByVal instrSession As Integer) As Integer
    Declare Function rsesci_HoldScan Lib "rsesci_32.dll" (ByVal instrSession As Integer) As Integer
    Declare Function rsesci_ContinueScan Lib "rsesci_32.dll" (ByVal instrSession As Integer) As Integer
    Declare Function rsesci_StopScan Lib "rsesci_32.dll" (ByVal instrSession As Integer) As Integer
    Declare Function rsesci_SetScanMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanMode As Int32) As Integer
    Declare Function rsesci_GetScanMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef scanMode As Int32) As Integer
    Declare Function rsesci_SetScanTimeDomain Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal measurementTime As Double) As Integer
    Declare Function rsesci_GetScanTimeDomain Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef measurementTime As Double) As Integer
    Declare Function rsesci_SetScanDisplaySpacing Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal displaySpacing As Int32) As Integer
    Declare Function rsesci_GetScanDisplaySpacing Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef displaySpacing As Int32) As Integer
    Declare Function rsesci_SetScanRanges Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal number_of_ranges As Int32) As Integer
    Declare Function rsesci_GetScanRanges Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef number_of_ranges As Int32) As Integer
    Declare Function rsesci_SetScanStart Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByVal startFrequency As Double) As Integer
    Declare Function rsesci_GetScanStart Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByRef startFrequency As Double) As Integer
    Declare Function rsesci_SetScanStop Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByVal stopFrequency As Double) As Integer
    Declare Function rsesci_GetScanStop Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByRef stopFrequency As Double) As Integer
    Declare Function rsesci_SetScanStepSize Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByVal stepSize As Double) As Integer
    Declare Function rsesci_GetScanStepSize Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByRef stepSize As Double) As Integer
    Declare Function rsesci_SetScanBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByVal bandwidth As Double) As Integer
    Declare Function rsesci_GetScanBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByRef bandwidth As Double) As Integer
    Declare Function rsesci_SetScanMeasurementTime Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByVal measurementTime As Double) As Integer
    Declare Function rsesci_GetScanMeasurementTime Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByRef measurementTime As Double) As Integer
    Declare Function rsesci_SetScanAutoRanging Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByVal autoRanging As Integer) As Integer
    Declare Function rsesci_GetScanAutoRanging Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByRef autoRanging As Integer) As Integer
    Declare Function rsesci_SetScanRFAttenuation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByVal attenuation As Double) As Integer
    Declare Function rsesci_GetScanRFAttenuation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByRef attenuation As Double) As Integer
    Declare Function rsesci_SetScanPreamplifier Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByVal preamplifierState As Integer) As Integer
    Declare Function rsesci_GetScanPreamplifier Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByRef preamplifierState As Integer) As Integer
    Declare Function rsesci_SetScanAutoPreamplifier Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByVal preamplifierInAutoranging As Integer) As Integer
    Declare Function rsesci_GetScanAutoPreamplifier Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal scanRange As Int32, ByRef preamplifierInAutoranging As Integer) As Integer
    Declare Function rsesci_SetMarker Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal x_state As Integer) As Integer
    Declare Function rsesci_GetMarker Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByRef x_state As Integer) As Integer
    Declare Function rsesci_AllMarkersOff Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32) As Integer
    Declare Function rsesci_SetMarkerPosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal x As Double) As Integer
    Declare Function rsesci_GetMarkerPosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByRef x As Double) As Integer
    Declare Function rsesci_GetMarkerValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByRef y As Double) As Integer
    Declare Function rsesci_SetMarkerZoom Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal zoom As Double) As Integer
    Declare Function rsesci_GetMarkerZoom Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef zoom As Double) As Integer
    Declare Function rsesci_SetMarkerFrequencyCounter Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal counterState As Integer) As Integer
    Declare Function rsesci_GetMarkerFrequencyCounter Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByRef counterState As Integer) As Integer
    Declare Function rsesci_SetMarkerFrequencyCounterResolution Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal resolution As Double) As Integer
    Declare Function rsesci_GetMarkerFrequencyCounterResolution Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef resolution As Double) As Integer
    Declare Function rsesci_GetMarkerFrequencyCounterValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByRef frequencyCounterValue As Double) As Integer
    Declare Function rsesci_SetDeltaMarker Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal x_state As Integer) As Integer
    Declare Function rsesci_GetDeltaMarker Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByRef x_state As Integer) As Integer
    Declare Function rsesci_AllDeltaMarkersOff Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32) As Integer
    Declare Function rsesci_SetDeltaMarkerMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal deltaMarkerMode As Int32) As Integer
    Declare Function rsesci_GetDeltaMarkerMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef deltaMarkerMode As Int32) As Integer
    Declare Function rsesci_SetDeltaMarkerPosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal position As Double) As Integer
    Declare Function rsesci_GetDeltaMarkerPosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByRef position As Double) As Integer
    Declare Function rsesci_GetDeltaMarkerRelativePosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByRef position As Double) As Integer
    Declare Function rsesci_GetDeltaMarkerValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByRef y As Double) As Integer
    Declare Function rsesci_SetDeltaMarkerReferenceFixed Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal fixedReferenceValue As Integer) As Integer
    Declare Function rsesci_GetDeltaMarkerReferenceFixed Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef fixedReferenceValue As Integer) As Integer
    Declare Function rsesci_SetDeltaMarkerReferencePointLevel Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal referencePointLevel As Double) As Integer
    Declare Function rsesci_GetDeltaMarkerReferencePointLevel Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef referencePointLevel As Double) As Integer
    Declare Function rsesci_SetDeltaMarkerReferencePointToPeak Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32) As Integer
    Declare Function rsesci_SetDeltaMarkerReferencePointLevelOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal offset As Double) As Integer
    Declare Function rsesci_GetDeltaMarkerReferencePointLevelOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef offset As Double) As Integer
    Declare Function rsesci_SetDeltaMarkerReferencePointPosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal referencePoint As Double) As Integer
    Declare Function rsesci_GetDeltaMarkerReferencePointPosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef referencePoint As Double) As Integer
    Declare Function rsesci_MarkerSearch Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal searchMode As Int32) As Integer
    Declare Function rsesci_SetMarkerTo Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal mkrFunction As Int32) As Integer
    Declare Function rsesci_SetMarkerToTrace Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal trace As Int32) As Integer
    Declare Function rsesci_GetMarkerToTrace Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByRef trace As Int32) As Integer
    Declare Function rsesci_SetPeakExcursion Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal peakExcursion As Double) As Integer
    Declare Function rsesci_GetPeakExcursion Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef peakExcursion As Double) As Integer
    Declare Function rsesci_SetLocalOscillatorSuppression Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal localOscillatorSuppression As Integer) As Integer
    Declare Function rsesci_GetLocalOscillatorSuppression Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef localOscillatorSuppression As Integer) As Integer
    Declare Function rsesci_SetMarkerSettingsCoupled Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal couplingState As Integer) As Integer
    Declare Function rsesci_GetMarkerSettingsCoupled Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByRef couplingState As Integer) As Integer
    Declare Function rsesci_DeltaMarkerSearch Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal searchMode As Int32) As Integer
    Declare Function rsesci_SetDeltaMarkerToTrace Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal trace As Int32) As Integer
    Declare Function rsesci_GetDeltaMarkerToTrace Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByRef trace As Int32) As Integer
    Declare Function rsesci_SetSearchLimitLines Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limitedRange As Integer) As Integer
    Declare Function rsesci_GetSearchLimitLines Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef limitedRange As Integer) As Integer
    Declare Function rsesci_SetSearchLeftLimitLine Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal leftLimit As Double) As Integer
    Declare Function rsesci_GetSearchLeftLimitLine Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef leftLimit As Double) As Integer
    Declare Function rsesci_SetSearchRightLimitLine Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal rightLimit As Double) As Integer
    Declare Function rsesci_GetSearchRightLimitLine Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef rightLimit As Double) As Integer
    Declare Function rsesci_SetSearchThreshold Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal searchThreshold As Integer) As Integer
    Declare Function rsesci_GetSearchThreshold Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef searchThreshold As Integer) As Integer
    Declare Function rsesci_SetSearchThresholdLine Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal threshold As Double) As Integer
    Declare Function rsesci_GetSearchThresholdLine Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef threshold As Double) As Integer
    Declare Function rsesci_SetNoiseDensityMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal noiseMeasurement As Integer) As Integer
    Declare Function rsesci_GetNoiseDensityMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef noiseMeasurement As Integer) As Integer
    Declare Function rsesci_GetNoiseDensityMeasurementValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef noiseMeasurement As Double) As Integer
    Declare Function rsesci_SetPhaseNoiseMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal phaseNoiseMeasurement As Integer) As Integer
    Declare Function rsesci_GetPhaseNoiseMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef phaseNoiseMeasurement As Integer) As Integer
    Declare Function rsesci_GetPhaseNoiseMeasurementValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef phaseNoiseMeasurement As Double) As Integer
    Declare Function rsesci_SetNdBDown Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal n_dBDownState As Integer) As Integer
    Declare Function rsesci_GetNdBDown Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef n_dBDownState As Integer) As Integer
    Declare Function rsesci_SetNdBDownLevelSpacing Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal levelSpacing As Double) As Integer
    Declare Function rsesci_GetNdBDownLevelSpacing Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef levelSpacing As Double) As Integer
    Declare Function rsesci_GetNdBDownBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef frequencySpacing As Double) As Integer
    Declare Function rsesci_GetNdBDownFrequencies Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef frequencies As Double) As Integer
    Declare Function rsesci_GetNdBDownTimes Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef times As Double) As Integer
    Declare Function rsesci_SearchForPeakList Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal number_of_maxima As Int32) As Integer
    Declare Function rsesci_SetPeakListSortMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal sortMode As Int32) As Integer
    Declare Function rsesci_GetPeakListSortMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef sortMode As Int32) As Integer
    Declare Function rsesci_GetPeakListCount Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef peakCount As Int32) As Integer
    Declare Function rsesci_GetPeakListXValues Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef xValues As Double) As Integer
    Declare Function rsesci_GetPeakListYValues Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef yValues As Double) As Integer
    Declare Function rsesci_SetMarkerDemodulation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal demodulationState As Integer) As Integer
    Declare Function rsesci_GetMarkerDemodulation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByRef demodulationState As Integer) As Integer
    Declare Function rsesci_SetMarkerDemodulationType Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal demodulationType As Int32) As Integer
    Declare Function rsesci_GetMarkerDemodulationType Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef demodulationType As Int32) As Integer
    Declare Function rsesci_SetMarkerStopTime Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal holdoff As Double) As Integer
    Declare Function rsesci_GetMarkerStopTime Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef holdoff As Double) As Integer
    Declare Function rsesci_SetContinuousMarkerDemodulation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal continuousDemodulation As Integer) As Integer
    Declare Function rsesci_GetContinuousMarkerDemodulation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef continuousDemodulation As Integer) As Integer
    Declare Function rsesci_SetTimeDomainPower Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal powerMeasurement As Int32, ByVal measurementState As Integer) As Integer
    Declare Function rsesci_GetTimeDomainPower Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal powerMeasurement As Int32, ByRef measurementState As Integer) As Integer
    Declare Function rsesci_SetTimeDomainPowerAveraging Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal averaging As Integer) As Integer
    Declare Function rsesci_GetTimeDomainPowerAveraging Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef averaging As Integer) As Integer
    Declare Function rsesci_SetTimeDomainPowerPeakHold Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal peakHold As Integer) As Integer
    Declare Function rsesci_GetTimeDomainPowerPeakHold Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef peakHold As Integer) As Integer
    Declare Function rsesci_SetTimeDomainPowerMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal mode As Int32) As Integer
    Declare Function rsesci_GetTimeDomainPowerMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef mode As Int32) As Integer
    Declare Function rsesci_SetTimeDomainPowerReference Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32) As Integer
    Declare Function rsesci_GetTimeDomainPowerMeanValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal resultType As Int32, ByRef result As Double) As Integer
    Declare Function rsesci_GetTimeDomainPowerPeakValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal resultType As Int32, ByRef result As Double) As Integer
    Declare Function rsesci_GetTimeDomainPowerRMSValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal resultType As Int32, ByRef result As Double) As Integer
    Declare Function rsesci_GetTimeDomainPowerStandardDeviationValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal resultType As Int32, ByRef result As Double) As Integer
    Declare Function rsesci_GetTimeDomainPowerSignalPulsesValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal time_offset_of_first_pulse As Double, ByVal measurementTime As Double, ByVal period As Double, ByVal pulses As Int32, ByRef result As Double) As Integer
    Declare Function rsesci_SetPowerMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal measurement As Int32) As Integer
    Declare Function rsesci_GetPowerMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef measurement As Int32) As Integer
    Declare Function rsesci_AdjustPowerMeasurementSetting Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal measurement As Int32) As Integer
    Declare Function rsesci_AdjustReferenceLevel Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32) As Integer
    Declare Function rsesci_GetPowerMeasurementValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal measurement As Int32, ByVal arraySize As Int32, ByRef result As Double) As Integer
    Declare Function rsesci_SetChannelPowerHzMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal relativeResult As Integer) As Integer
    Declare Function rsesci_GetChannelPowerHzMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef relativeResult As Integer) As Integer
    Declare Function rsesci_SetCPACPStandard Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal standard As Int32) As Integer
    Declare Function rsesci_GetCPACPStandard Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef standard As Int32) As Integer
    Declare Function rsesci_SetCPReference Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32) As Integer
    Declare Function rsesci_SetNoiseCorrection Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal correction As Integer) As Integer
    Declare Function rsesci_GetNoiseCorrection Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef correction As Integer) As Integer
    Declare Function rsesci_SetFastACP Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal fastACP As Integer) As Integer
    Declare Function rsesci_GetFastACP Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef fastACP As Integer) As Integer
    Declare Function rsesci_SetFullSizeDiagram Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal x_size As Int32) As Integer
    Declare Function rsesci_GetFullSizeDiagram Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef x_size As Int32) As Integer
    Declare Function rsesci_SetNumberAdjacentChannels Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal number_ofAdjacentChannels As Int32) As Integer
    Declare Function rsesci_GetNumberAdjacentChannels Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef number_ofAdjacentChannels As Int32) As Integer
    Declare Function rsesci_SetNumberTXChannels Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal number_ofCarriers As Int32) As Integer
    Declare Function rsesci_GetNumberTXChannels Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef number_ofCarriers As Int32) As Integer
    Declare Function rsesci_SetTXACPChannelBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal channelBandwidth As Int32, ByVal channelBandwidthValue As Double) As Integer
    Declare Function rsesci_GetTXACPChannelBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal channelBandwidth As Int32, ByRef channelBandwidthValue As Double) As Integer
    Declare Function rsesci_SetACPChannelSpacing Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal channelSpacing As Int32, ByVal channelSpacingValue As Double) As Integer
    Declare Function rsesci_GetACPChannelSpacing Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal channelSpacing As Int32, ByRef channelSpacingValue As Double) As Integer
    Declare Function rsesci_SetACPReferenceChannel Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal ACPReferenceChannel As Int32) As Integer
    Declare Function rsesci_SetCPACPPowerMeasurementMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal mode As Int32) As Integer
    Declare Function rsesci_GetCPACPPowerMeasurementMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef mode As Int32) As Integer
    Declare Function rsesci_SetCPACPMeasurementTrace Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32) As Integer
    Declare Function rsesci_GetCPACPMeasurementTrace Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef trace As Int32) As Integer
    Declare Function rsesci_SetACPLimitChecking Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limitChecking As Integer) As Integer
    Declare Function rsesci_GetACPLimitChecking Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef limitChecking As Integer) As Integer
    Declare Function rsesci_SetACPLimits Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limitType As Int32, ByVal mode As Int32, ByVal x_state As Integer, ByVal limitValue As Double) As Integer
    Declare Function rsesci_GetACPLimits Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal mode As Int32, ByVal limitType As Int32, ByRef x_state As Integer, ByRef limitValue As Double) As Integer
    Declare Function rsesci_GetACPLimitCheckingResult Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limitType As Int32, ByRef result As Integer) As Integer
    Declare Function rsesci_SetPowerBandwidthPercentage Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal percentage As Double) As Integer
    Declare Function rsesci_GetPowerBandwidthPercentage Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef percentage As Double) As Integer
    Declare Function rsesci_SetChannelBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal channelBandwidth As Double) As Integer
    Declare Function rsesci_GetChannelBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef channelBandwidth As Double) As Integer
    Declare Function rsesci_SetSignalAmplitudeStatistics Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal measurement As Int32) As Integer
    Declare Function rsesci_GetSignalAmplitudeStatistics Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef measurement As Int32) As Integer
    Declare Function rsesci_SetCCDFPercentMarker Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal position As Double) As Integer
    Declare Function rsesci_GetCCDFPercentMarker Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByRef position As Double) As Integer
    Declare Function rsesci_SetStatisticsNumberSamples Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal numberOfSamples As Double) As Integer
    Declare Function rsesci_GetStatisticsNumberSamples Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef numberOfSamples As Double) As Integer
    Declare Function rsesci_StatisticsAdjustSettings Lib "rsesci_32.dll" (ByVal instrSession As Integer) As Integer
    Declare Function rsesci_StatisticsDefaultSettings Lib "rsesci_32.dll" (ByVal instrSession As Integer) As Integer
    Declare Function rsesci_GetStatisticalMeasurementsResults Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal trace As Int32, ByVal resultType As Int32, ByRef result As Double) As Integer
    Declare Function rsesci_SetStatisticsXAxisReferenceLevel Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal referenceLevel As Double) As Integer
    Declare Function rsesci_GetStatisticsXAxisReferenceLevel Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef referenceLevel As Double) As Integer
    Declare Function rsesci_SetStatisticsXAxisRange Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal range As Double) As Integer
    Declare Function rsesci_GetStatisticsXAxisRange Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef range As Double) As Integer
    Declare Function rsesci_SetStatisticsYAxisMinValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal minValue As Double) As Integer
    Declare Function rsesci_GetStatisticsYAxisMinValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef minValue As Double) As Integer
    Declare Function rsesci_SetStatisticsYAxisMaxValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal maxValue As Double) As Integer
    Declare Function rsesci_GetStatisticsYAxisMaxValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef maxValue As Double) As Integer
    Declare Function rsesci_SetModulationDepthMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal modulationDepthMeasurement As Integer) As Integer
    Declare Function rsesci_GetModulationDepthMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef modulationDepthMeasurement As Integer) As Integer
    Declare Function rsesci_GetModulationDepthMeasurementValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef result As Double) As Integer
    Declare Function rsesci_SetThirdOrderInterceptMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_state As Integer) As Integer
    Declare Function rsesci_GetThirdOrderInterceptMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef x_state As Integer) As Integer
    Declare Function rsesci_GetThirdOrderInterceptMeasurementValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef TOIResult As Double) As Integer
    Declare Function rsesci_SetMultiplePowerMeasurementParameters Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal peakDetector As Integer, ByVal RMSDetector As Integer, ByVal averageDetector As Integer, ByVal triggerMode As Int32, ByVal triggerSlope As Int32, ByVal triggerOffset As Double, ByVal gateLength As Double) As Integer
    Declare Function rsesci_GetMultiplePowerMeasurementParameters Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef peakDetector As Integer, ByRef RMSDetector As Integer, ByRef averageDetector As Integer, ByRef triggerMode As Int32, ByRef triggerSlope As Int32, ByRef triggerOffset As Double, ByRef gateLength As Double) As Integer
    Declare Function rsesci_MultiplePowerMeasurementSequence Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal number_ofEntries As Int32, ByRef analyzerFrequency As Double, ByRef referenceLevel As Double, ByRef RFInputAttenuation As Double, ByRef filterType As Int32, ByRef resolutionBandwidth As Double, ByRef videoBandwidth As Double, ByRef measurementTime As Double, ByRef triggerLevel As Double) As Integer
    Declare Function rsesci_MultiplePowerMeasurementResults Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef number_ofResults As Int32, ByRef powerMeasurementResults As Double) As Integer
    Declare Function rsesci_DeactivateMultiplePowerMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32) As Integer
    Declare Function rsesci_MultipleBurstPowerMeasurementSequence Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal analyzerFrequency As Double, ByVal resolutionBandwidth As Double, ByVal measurementTime As Double, ByVal triggerSource As Int32, ByVal triggerLevel As Double, ByVal triggerOffset As Double, ByVal measurementType As Int32, ByVal no_ofMeasurements As Int32) As Integer
    Declare Function rsesci_MultipleBurstPowerMeasurementResult Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef powerMeasurementResults As Double, ByRef number_ofResults As Int32) As Integer
    Declare Function rsesci_MultipleBurstPowerMeasurementResultMinimum Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef powerMeasurementResult As Double) As Integer
    Declare Function rsesci_SetReceiverDetector Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal maxPeak As Integer, ByVal minPeak As Integer, ByVal RMS As Integer, ByVal average As Integer, ByVal quasipeak As Integer, ByVal CISPRAverage As Integer) As Integer
    Declare Function rsesci_GetReceiverDetector Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef maxPeak As Integer, ByRef minPeak As Integer, ByRef RMS As Integer, ByRef average As Integer, ByRef quasipeak As Integer, ByRef CISPRAverage As Integer) As Integer
    Declare Function rsesci_SetFinalReceiverDetector Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32, ByVal finalDetector As Int32) As Integer
    Declare Function rsesci_GetFinalReceiverDetector Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32, ByRef finalDetector As Int32) As Integer
    Declare Function rsesci_PeakSearch Lib "rsesci_32.dll" (ByVal instrSession As Integer) As Integer
    Declare Function rsesci_SetPeakSearchMethod Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal searchMethod As Int32) As Integer
    Declare Function rsesci_GetPeakSearchMethod Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef searchMethod As Int32) As Integer
    Declare Function rsesci_SetPeakSearchMargin Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal margin As Double) As Integer
    Declare Function rsesci_GetPeakSearchMargin Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef margin As Double) As Integer
    Declare Function rsesci_SetPeakSearchSubranges Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal subranges As Int32) As Integer
    Declare Function rsesci_GetPeakSearchSubranges Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef subranges As Int32) As Integer
    Declare Function rsesci_SetPeakSearchListDisplay Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32, ByVal indication As Int32) As Integer
    Declare Function rsesci_GetPeakSearchListDisplay Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32, ByRef indication As Int32) As Integer
    Declare Function rsesci_SetThresholdScan Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal thresholdScan As Integer) As Integer
    Declare Function rsesci_GetThresholdScan Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef thresholdScan As Integer) As Integer
    Declare Function rsesci_SetNBBBDiscrimination Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal discriminationState As Integer) As Integer
    Declare Function rsesci_GetNBBBDiscrimination Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef discriminationState As Integer) As Integer
    Declare Function rsesci_SetNBBBDiscriminationValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal discriminationThreshold As Double) As Integer
    Declare Function rsesci_GetNBBBDiscriminationValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef discriminationThreshold As Double) As Integer
    Declare Function rsesci_SetFinalMeasurementTime Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal measurementTime As Double) As Integer
    Declare Function rsesci_GetFinalMeasurementTime Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef measurementTime As Double) As Integer
    Declare Function rsesci_SetFinalMeasurementAuto Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal automaticMeasurement As Integer) As Integer
    Declare Function rsesci_GetFinalMeasurementAuto Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef automaticMeasurement As Integer) As Integer
    Declare Function rsesci_SetVnetworkType Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal measurement As Int32, ByVal vnetwork As Int32) As Integer
    Declare Function rsesci_GetVnetworkType Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal measurement As Int32, ByRef vnetwork As Int32) As Integer
    Declare Function rsesci_SetVnetworkProtectionEarth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal measurement As Int32, ByVal protectiveEarth As Int32) As Integer
    Declare Function rsesci_GetVnetworkProtectionEarth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal measurement As Int32, ByRef protectiveEarth As Int32) As Integer
    Declare Function rsesci_SetVnetworkPhase Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal measurement As Int32, ByVal phase As Int32) As Integer
    Declare Function rsesci_GetVnetworkPhase Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal measurement As Int32, ByRef phase As Int32) As Integer
    Declare Function rsesci_SetDemodulationType Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal demodulation As Int32) As Integer
    Declare Function rsesci_GetDemodulationType Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef demodulation As Int32) As Integer
    Declare Function rsesci_ReadReceiverDetector Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef firstDetector As Double, ByRef secondDetector As Double, ByRef thirdDetector As Double) As Integer
    Declare Function rsesci_ReadReceiverDetectorPeakHold Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef firstDetector As Double, ByRef secondDetector As Double, ByRef thirdDetector As Double) As Integer
    Declare Function rsesci_ReadScanMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal arraySize As Int32, ByRef traceStatus As Int32, ByRef number_ofResults As Int32, ByRef statusData As Byte, ByRef results_ofTrace1 As Double, ByRef results_ofTrace2 As Double, ByRef results_ofTrace3 As Double) As Integer
    Declare Function rsesci_ReadScanMeasurementStatus Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal arraySize As Int32, ByRef number_ofResults As Int32, ByVal statusData As String) As Integer
    Declare Function rsesci_ReadFinalMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal trace As Int32, ByVal arraySize As Int32, ByRef number_ofResults As Int32, ByRef frequency As Double, ByRef level As Double, ByRef deltaLimit As Double) As Integer
    Declare Function rsesci_SetInstrumentMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal instrumentMode As Int32) As Integer
    Declare Function rsesci_GetInstrumentMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef instrumentMode As Int32) As Integer
    Declare Function rsesci_SetMixedInstrumentMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal mixedMode As Integer, ByVal screens As Int32) As Integer
    Declare Function rsesci_GetMixedInstrumentMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef mixedMode As Integer, ByRef screens As Int32) As Integer
    Declare Function rsesci_SetTrackingGenerator Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trackingGenerator As Integer) As Integer
    Declare Function rsesci_GetTrackingGenerator Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef trackingGenerator As Integer) As Integer
    Declare Function rsesci_SetTrackingGeneratorSourcePower Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal outputLevel As Double) As Integer
    Declare Function rsesci_GetTrackingGeneratorSourcePower Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef outputLevel As Double) As Integer
    Declare Function rsesci_SetTrackingGeneratorPowerOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal levelOffset As Double) As Integer
    Declare Function rsesci_GetTrackingGeneratorPowerOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef levelOffset As Double) As Integer
    Declare Function rsesci_SetTrackingGeneratorFrequencyOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal frequencyOffset As Double) As Integer
    Declare Function rsesci_GetTrackingGeneratorFrequencyOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef frequencyOffset As Double) As Integer
    Declare Function rsesci_SetTrackingGeneratorMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal measurementType As Int32) As Integer
    Declare Function rsesci_GetTrackingGeneratorMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef measurementType As Int32) As Integer
    Declare Function rsesci_SetTrackingGeneratorNormalization Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal normalization As Integer) As Integer
    Declare Function rsesci_GetTrackingGeneratorNormalization Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef normalization As Integer) As Integer
    Declare Function rsesci_TrackingGeneratorCalibration Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal acquisitionType As Int32) As Integer
    Declare Function rsesci_TrackingGeneratorRecallSettings Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32) As Integer
    Declare Function rsesci_SetExternalAM Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal externalAM As Integer) As Integer
    Declare Function rsesci_GetExternalAM Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef externalAM As Integer) As Integer
    Declare Function rsesci_SetExternalFM Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal externalFM As Integer) As Integer
    Declare Function rsesci_GetExternalFM Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef externalFM As Integer) As Integer
    Declare Function rsesci_SetExternalIQModulation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal IQModulation As Integer) As Integer
    Declare Function rsesci_GetExternalIQModulation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef IQModulation As Integer) As Integer
    Declare Function rsesci_SetExternalFMDeviation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal FMDeviation As Double) As Integer
    Declare Function rsesci_GetExternalFMDeviation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef FMDeviation As Double) As Integer
    Declare Function rsesci_SetExternalGenerator Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal externalGenerator As Integer) As Integer
    Declare Function rsesci_GetExternalGenerator Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef externalGenerator As Integer) As Integer
    Declare Function rsesci_SetExternalGeneratorSelection Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal generator As Int32, ByVal intf As Int32, ByVal x_type As String, ByVal GPIBAddress As Int32) As Integer
    Declare Function rsesci_GetExternalGeneratorSelection Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal generator As Int32, ByRef intf As Int32, ByVal x_type As String, ByRef GPIBAddress As Int32) As Integer
    Declare Function rsesci_SetExternalGeneratorFrequencyOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal generator As Int32, ByVal offset As Double) As Integer
    Declare Function rsesci_GetExternalGeneratorFrequencyOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal generator As Int32, ByRef offset As Double) As Integer
    Declare Function rsesci_SetExternalGeneratorMultiplicationFactor Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal generator As Int32, ByVal numerator As Int32, ByVal denominator As Int32) As Integer
    Declare Function rsesci_GetExternalGeneratorMultiplicationFactor Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal generator As Int32, ByRef numerator As Int32, ByRef denominator As Int32) As Integer
    Declare Function rsesci_SetExternalGeneratorFrequencySweep Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal generator As Int32, ByVal sweep As Integer) As Integer
    Declare Function rsesci_GetExternalGeneratorFrequencySweep Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal generator As Int32, ByRef sweep As Integer) As Integer
    Declare Function rsesci_SetExternalGeneratorPower Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal generator As Int32, ByVal power As Double) As Integer
    Declare Function rsesci_GetExternalGeneratorPower Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal generator As Int32, ByRef power As Double) As Integer
    Declare Function rsesci_SetExternalGeneratorReferenceOscillator Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal generator As Int32, ByVal referenceOscillator As Int32) As Integer
    Declare Function rsesci_GetExternalGeneratorReferenceOscillator Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal generator As Int32, ByRef referenceOscillator As Int32) As Integer
    Declare Function rsesci_SetAnalogDemodulator Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal analogDemodulator As Integer) As Integer
    Declare Function rsesci_GetAnalogDemodulator Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef analogDemodulator As Integer) As Integer
    Declare Function rsesci_SetAnalogDemodulatorParameters Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal sampleRate As Double, ByVal recordLength As Int32, ByVal triggerSource As Int32, ByVal triggerSlope As Int32, ByVal offsetSamples As Int32, ByVal number_ofMeas As Int32) As Integer
    Declare Function rsesci_GetAnalogDemodulatorParameters Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef sampleRate As Double, ByRef recordLength As Int32, ByRef triggerSource As Int32, ByRef triggerSlope As Int32, ByRef offsetSamples As Int32, ByRef number_ofMeas As Int32) As Integer
    Declare Function rsesci_SetAnalogDemodulatorResultDisplay Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal resultDisplay As Int32, ByVal trace As Int32) As Integer
    Declare Function rsesci_SetAnalogDemodulationMeasurementTime Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal measurementTime As Double) As Integer
    Declare Function rsesci_GetAnalogDemodulationMeasurementTime Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef measurementTime As Double) As Integer
    Declare Function rsesci_GetAnalogDemodulationSampleRate Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef sampleRate As Double) As Integer
    Declare Function rsesci_GetAnalogDemodulationRecordLength Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef recordLength As Double) As Integer
    Declare Function rsesci_SetAFCenterFrequency Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal centerFrequency As Double) As Integer
    Declare Function rsesci_GetAFCenterFrequency Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef centerFrequency As Double) As Integer
    Declare Function rsesci_SetAFStartFrequency Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal startFrequency As Double) As Integer
    Declare Function rsesci_GetAFStartFrequency Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef startFrequency As Double) As Integer
    Declare Function rsesci_SetAFStopFrequency Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal stopFrequency As Double) As Integer
    Declare Function rsesci_GetAFStopFrequency Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef stopFrequency As Double) As Integer
    Declare Function rsesci_SetAFSpan Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal span As Double) As Integer
    Declare Function rsesci_GetAFSpan Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef span As Double) As Integer
    Declare Function rsesci_SetRFFrequencySpan Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal span As Double) As Integer
    Declare Function rsesci_GetRFFrequencySpan Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef span As Double) As Integer
    Declare Function rsesci_SetMaxRFFrequencySpan Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal span As Double) As Integer
    Declare Function rsesci_GetMaxRFFrequencySpan Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef span As Double) As Integer
    Declare Function rsesci_SetAnalogDemodulationBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal demodulationBandwidth As Double) As Integer
    Declare Function rsesci_GetAnalogDemodulationBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef demodulationBandwidth As Double) As Integer
    Declare Function rsesci_SetAnalogDemodulationResolutionBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal resolutionBandwidth As Double) As Integer
    Declare Function rsesci_GetAnalogDemodulationResolutionBandwidth Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef resolutionBandwidth As Double) As Integer
    Declare Function rsesci_SetAFInputCoupling Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal AFInputCoupling As Int32) As Integer
    Declare Function rsesci_GetAFInputCoupling Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef AFInputCoupling As Int32) As Integer
    Declare Function rsesci_SetAnalogDemodulationAngleUnits Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal angleUnits As Int32) As Integer
    Declare Function rsesci_GetAnalogDemodulationAngleUnits Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef angleUnits As Int32) As Integer
    Declare Function rsesci_SetAnalogDemodulationZoom Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal zoom As Integer) As Integer
    Declare Function rsesci_GetAnalogDemodulationZoom Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef zoom As Integer) As Integer
    Declare Function rsesci_SetAnalogDemodulationZoomStart Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal zoomStart As Double) As Integer
    Declare Function rsesci_GetAnalogDemodulationZoomStart Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef zoomStart As Double) As Integer
    Declare Function rsesci_GetFMModulationMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal trace As Int32, ByVal measurement As Int32, ByRef result As Double) As Integer
    Declare Function rsesci_GetPMModulationMeasurement Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal trace As Int32, ByVal measurement As Int32, ByRef result As Double) As Integer
    Declare Function rsesci_GetAnalogDemodulationAudioFrequency Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal trace As Int32, ByRef result As Double) As Integer
    Declare Function rsesci_GetAnalogDemodulationFrequencyError Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal trace As Int32, ByRef result As Double) As Integer
    Declare Function rsesci_GetAnalogDemodulationSINAD Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal trace As Int32, ByRef result As Double) As Integer
    Declare Function rsesci_GetAnalogDemodulationTHD Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal trace As Int32, ByRef result As Double) As Integer
    Declare Function rsesci_GetAnalogDemodulationCarrierPower Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal marker As Int32, ByVal trace As Int32, ByRef result As Double) As Integer
    Declare Function rsesci_SetAFSpectrumResultTypes Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal demodulationType As Int32, ByVal resultType1 As Int32, ByVal resultType2 As Int32, ByVal resultType3 As Int32) As Integer
    Declare Function rsesci_GetAFSpectrumResultValues Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal demodulationType As Int32, ByVal resultType As Int32, ByVal arraySize As Int32, ByRef number_ofResults As Int32, ByRef results As Double) As Integer
    Declare Function rsesci_SetRFSpectrumResultTypes Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal resultType1 As Int32, ByVal resultType2 As Int32, ByVal resultType3 As Int32) As Integer
    Declare Function rsesci_GetRFSpectrumResultValues Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal resultType As Int32, ByVal arraySize As Int32, ByRef number_ofResults As Int32, ByRef results As Double) As Integer
    Declare Function rsesci_SetTimeDomainResultTypes Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal demodulationType As Int32, ByVal resultType1 As Int32, ByVal resultType2 As Int32, ByVal resultType3 As Int32) As Integer
    Declare Function rsesci_GetTimeDomainResultValues Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal demodulationType As Int32, ByVal resultType As Int32, ByVal arraySize As Int32, ByRef number_ofResults As Int32, ByRef results As Double) As Integer
    Declare Function rsesci_GetFMOffsetValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal measurement As Int32, ByRef result As Double) As Integer
    Declare Function rsesci_SetDataAveraging Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32, ByVal dataAveraging As Integer) As Integer
    Declare Function rsesci_GetDataAveraging Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal trace As Int32, ByRef dataAveraging As Integer) As Integer
    Declare Function rsesci_SetAverageCount Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal averageCount As Int32) As Integer
    Declare Function rsesci_GetAverageCount Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef averageCount As Int32) As Integer
    Declare Function rsesci_SetAverageType Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal averageType As Int32) As Integer
    Declare Function rsesci_GetAverageType Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef averageType As Int32) As Integer
    Declare Function rsesci_SetLimitLineName Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal x_name As String) As Integer
    Declare Function rsesci_GetLimitLineName Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal x_name As String) As Integer
    Declare Function rsesci_SetLimitLineVisible Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limit As Int32, ByVal limitType As Int32, ByVal x_state As Integer) As Integer
    Declare Function rsesci_GetLimitLineVisible Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limit As Int32, ByVal limitType As Int32, ByRef x_state As Integer) As Integer
    Declare Function rsesci_SetLimitLineTrace Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limit As Int32, ByVal trace As Int32) As Integer
    Declare Function rsesci_GetLimitLineTrace Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limit As Int32, ByRef trace As Int32) As Integer
    Declare Function rsesci_CopyLimitLine Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal sourceLimit As Int32, ByVal destinationLimit As Int32) As Integer
    Declare Function rsesci_DeleteLimitLine Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32) As Integer
    Declare Function rsesci_SetLimitLineXOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limit As Int32, ByVal offset As Double) As Integer
    Declare Function rsesci_GetLimitLineXOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limit As Int32, ByRef offset As Double) As Integer
    Declare Function rsesci_SetLimitLineYOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal limitType As Int32, ByVal offset As Double) As Integer
    Declare Function rsesci_GetLimitLineYOffset Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal limitType As Int32, ByRef offset As Double) As Integer
    Declare Function rsesci_SetLimitLineCheck Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limit As Int32, ByVal limitCheck As Integer) As Integer
    Declare Function rsesci_GetLimitLineCheck Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limit As Int32, ByRef limitCheck As Integer) As Integer
    Declare Function rsesci_GetLimitLineCheckResult Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limit As Int32, ByRef result As Int32) As Integer
    Declare Function rsesci_ClearLimitLineCheckResult Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32) As Integer
    Declare Function rsesci_SetLimitLineDomain Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limit As Int32, ByVal domain As Int32) As Integer
    Declare Function rsesci_GetLimitLineDomain Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limit As Int32, ByRef domain As Int32) As Integer
    Declare Function rsesci_SetLimitLineInterpolation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limit As Int32, ByVal interpolationAxis As Int32, ByVal interpolation As Int32) As Integer
    Declare Function rsesci_GetLimitLineInterpolation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal limit As Int32, ByVal interpolationAxis As Int32, ByRef interpolation As Int32) As Integer
    Declare Function rsesci_SetLimitLineScaling Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal interpolationAxis As Int32, ByVal limitLineScaling As Int32) As Integer
    Declare Function rsesci_GetLimitLineScaling Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal interpolationAxis As Int32, ByRef limitLineScaling As Int32) As Integer
    Declare Function rsesci_SetLimitLineUnit Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal levelAxisUnit As Int32) As Integer
    Declare Function rsesci_GetLimitLineUnit Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByRef levelAxisUnit As Int32) As Integer
    Declare Function rsesci_SetLimitLineMargin Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal limitLineType As Int32, ByVal margin As Double) As Integer
    Declare Function rsesci_GetLimitLineMargin Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal limitLineType As Int32, ByRef margin As Double) As Integer
    Declare Function rsesci_SetLimitLineThreshold Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal limitLineType As Int32, ByVal threshold As Double) As Integer
    Declare Function rsesci_GetLimitLineThreshold Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal limitLineType As Int32, ByRef threshold As Double) As Integer
    Declare Function rsesci_SetLimitLineComment Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal comment As String) As Integer
    Declare Function rsesci_GetLimitLineComment Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal comment As String) As Integer
    Declare Function rsesci_SetLimitLineValues Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal axis As Int32, ByVal arraySize As Int32, ByRef x_data As Double) As Integer
    Declare Function rsesci_GetLimitLineValues Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal axis As Int32, ByVal arraySize As Int32, ByRef x_data As Double) As Integer
    Declare Function rsesci_LimitLineShiftX Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal x_shift As Double) As Integer
    Declare Function rsesci_LimitLineShiftY Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal limit As Int32, ByVal axisType As Int32, ByVal x_shift As Double) As Integer
    Declare Function rsesci_SetDisplayLine Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_line As Int32, ByVal x_state As Integer) As Integer
    Declare Function rsesci_GetDisplayLine Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_line As Int32, ByRef x_state As Integer) As Integer
    Declare Function rsesci_SetDisplayLinePosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_line As Int32, ByVal position As Double) As Integer
    Declare Function rsesci_GetDisplayLinePosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_line As Int32, ByRef position As Double) As Integer
    Declare Function rsesci_SetFrequencyLine Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_line As Int32, ByVal x_state As Integer) As Integer
    Declare Function rsesci_GetFrequencyLine Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_line As Int32, ByRef x_state As Integer) As Integer
    Declare Function rsesci_SetFrequencyLinePosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_line As Int32, ByVal position As Double) As Integer
    Declare Function rsesci_GetFrequencyLinePosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_line As Int32, ByRef position As Double) As Integer
    Declare Function rsesci_SetTimeLine Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_line As Int32, ByVal x_state As Integer) As Integer
    Declare Function rsesci_GetTimeLine Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_line As Int32, ByRef x_state As Integer) As Integer
    Declare Function rsesci_SetTimeLinePosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_line As Int32, ByVal position As Double) As Integer
    Declare Function rsesci_GetTimeLinePosition Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_line As Int32, ByRef position As Double) As Integer
    Declare Function rsesci_SetActiveWindow Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32) As Integer
    Declare Function rsesci_SetScreenMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal mode As Int32) As Integer
    Declare Function rsesci_GetScreenMode Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef mode As Int32) As Integer
    Declare Function rsesci_SetDisplaySize Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal displaySize As Int32) As Integer
    Declare Function rsesci_GetDisplaySize Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef displaySize As Int32) As Integer
    Declare Function rsesci_SetDisplayUpdate Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal displayUpdate As Integer) As Integer
    Declare Function rsesci_GetDisplayUpdate Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef displayUpdate As Integer) As Integer
    Declare Function rsesci_SetDisplayBargraphMaxhold Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal bargraphMaxhold As Integer) As Integer
    Declare Function rsesci_GetDisplayBargraphMaxhold Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef bargraphMaxhold As Integer) As Integer
    Declare Function rsesci_GetDisplayBargraphLevel Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef minimumBargraphLevel As Double, ByRef maximumBargraphLevel As Double) As Integer
    Declare Function rsesci_ResetDisplayBargraphMaxhold Lib "rsesci_32.dll" (ByVal instrSession As Integer) As Integer
    Declare Function rsesci_SetParameterCoupling Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal coupledParameters As Int32, ByVal coupling As Integer) As Integer
    Declare Function rsesci_GetParameterCoupling Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal coupledParameters As Int32, ByRef coupling As Integer) As Integer
    Declare Function rsesci_SetInstrumentCoupling Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal coupling As Int32) As Integer
    Declare Function rsesci_SetScreenTitle Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal screenTitle As Integer, ByVal commentString As String) As Integer
    Declare Function rsesci_SetDisplayElements Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal annotation As Integer, ByVal logo As Integer, ByVal timeDate As Integer) As Integer
    Declare Function rsesci_SetDisplayUserDefinedColors Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal colorMap As Int32, ByVal predefinedColors As Int32, ByVal tint As Double, ByVal saturation As Double, ByVal brightness As Double) As Integer
    Declare Function rsesci_SetDisplayDefaultColors Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal defaultColors As Int32) As Integer
    Declare Function rsesci_SetDisplayPowerSaving Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal powerSaving As Integer, ByVal holdoffTime As Int32) As Integer
    Declare Function rsesci_SetExternalReferenceOscillator Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal referenceOscillator As Int32) As Integer
    Declare Function rsesci_GetExternalReferenceOscillator Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef referenceOscillator As Int32) As Integer
    Declare Function rsesci_SetExternalNoiseSource Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal noiseSource As Integer) As Integer
    Declare Function rsesci_GetExternalNoiseSource Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef noiseSource As Integer) As Integer
    Declare Function rsesci_SetPreselector Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal preselector As Integer) As Integer
    Declare Function rsesci_GetPreselector Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef preselector As Integer) As Integer
    Declare Function rsesci_SetTransducerFactor Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal transducerFactor As Integer) As Integer
    Declare Function rsesci_GetTransducerFactor Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef transducerFactor As Integer) As Integer
    Declare Function rsesci_SetTransducerFactorName Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_name As String) As Integer
    Declare Function rsesci_GetTransducerFactorName Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_name As String) As Integer
    Declare Function rsesci_DeleteTransducerFactor Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_name As String) As Integer
    Declare Function rsesci_SetTransducerFactorView Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal transducerFactorView As Integer) As Integer
    Declare Function rsesci_GetTransducerFactorView Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef transducerFactorView As Integer) As Integer
    Declare Function rsesci_SetTransducerFactorAutoAdjust Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal autoAdjust As Integer) As Integer
    Declare Function rsesci_GetTransducerFactorAutoAdjust Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef autoAdjust As Integer) As Integer
    Declare Function rsesci_SetTransducerSet Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal transducerSet As Integer) As Integer
    Declare Function rsesci_GetTransducerSet Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef transducerSet As Integer) As Integer
    Declare Function rsesci_SetTransducerSetName Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_name As String) As Integer
    Declare Function rsesci_GetTransducerSetName Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_name As String) As Integer
    Declare Function rsesci_DeleteTransducerSet Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal x_name As String) As Integer
    Declare Function rsesci_SetTransducerFactorUnit Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal transducerFactorUnit As Int32) As Integer
    Declare Function rsesci_GetTransducerFactorUnit Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef transducerFactorUnit As Int32) As Integer
    Declare Function rsesci_SetTransducerFactorInterpolation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal transducerFactorInterpolation As Int32) As Integer
    Declare Function rsesci_GetTransducerFactorInterpolation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef transducerFactorInterpolation As Int32) As Integer
    Declare Function rsesci_SetTransducerFactorComment Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal comment As String) As Integer
    Declare Function rsesci_GetTransducerFactorComment Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal comment As String) As Integer
    Declare Function rsesci_SetTransducerFactorValues Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal arraySize As Int32, ByRef frequencyValues As Double, ByRef levelValues As Double) As Integer
    Declare Function rsesci_GetTransducerFactorValues Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef number_ofResults As Int32, ByRef frequencyValues As Double, ByRef levelValues As Double) As Integer
    Declare Function rsesci_SetTransducerSetUnit Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal transducerSetUnit As Int32) As Integer
    Declare Function rsesci_GetTransducerSetUnit Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef transducerSetUnit As Int32) As Integer
    Declare Function rsesci_SetTransducerSetBreak Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal transducerSetBreak As Integer) As Integer
    Declare Function rsesci_GetTransducerSetBreak Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef transducerSetBreak As Integer) As Integer
    Declare Function rsesci_SetTransducerSetComment Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal comment As String) As Integer
    Declare Function rsesci_GetTransducerSetComment Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal comment As String) As Integer
    Declare Function rsesci_SetTransducerSetValues Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal range As Int32, ByVal startFrequency As Double, ByVal stopFrequency As Double, ByVal factors As String) As Integer
    Declare Function rsesci_GetTransducerSetValues Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal range As Int32, ByRef startFrequency As Double, ByRef stopFrequency As Double, ByVal factors As String) As Integer
    Declare Function rsesci_SetGPIBAddress Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal GPIBAddress As Int32) As Integer
    Declare Function rsesci_GetGPIBAddress Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef GPIBAddress As Int32) As Integer
    Declare Function rsesci_SetSerialInterfaceConfiguration Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal baudRate As Int32, ByVal dataBits As Int32, ByVal stopBits As Int32, ByVal hardwareHandshake As Integer, ByVal softwareHandshake As Integer, ByVal x_parity As Int32) As Integer
    Declare Function rsesci_GetSerialInterfaceConfiguration Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef baudRate As Int32, ByRef dataBits As Int32, ByRef stopBits As Int32, ByRef hardwareHandshake As Integer, ByRef softwareHandshake As Integer, ByRef x_parity As Int32) As Integer
    Declare Function rsesci_SetSystemTime Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal hour As Int32, ByVal minute As Int32, ByVal second As Int32) As Integer
    Declare Function rsesci_GetSystemTime Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef hour As Int32, ByRef minute As Int32, ByRef second As Int32) As Integer
    Declare Function rsesci_SetSystemDate Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal day As Int32, ByVal month As Int32, ByVal year As Int32) As Integer
    Declare Function rsesci_GetSystemDate Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef day As Int32, ByRef month As Int32, ByRef year As Int32) As Integer
    Declare Function rsesci_SetSpeakerVolume Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal speakerVolume As Double) As Integer
    Declare Function rsesci_GetSpeakerVolume Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef speakerVolume As Double) As Integer
    Declare Function rsesci_SetSoftFrontpanel Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal softFrontpanel As Integer) As Integer
    Declare Function rsesci_GetSoftFrontpanel Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef softFrontpanel As Integer) As Integer
    Declare Function rsesci_SetUserPort Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal userPort As Int32) As Integer
    Declare Function rsesci_GetUserPort Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef userPort As Int32) As Integer
    Declare Function rsesci_ReadUserPortValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef userPortValue As Integer) As Integer
    Declare Function rsesci_WriteUserPortValue Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef userPortValue As Integer) As Integer
    Declare Function rsesci_SetServiceSource Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal serviceSource As Int32, ByVal calibrationSourceLevel As Double) As Integer
    Declare Function rsesci_GetServiceSource Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef serviceSource As Int32, ByRef calibrationSourceLevel As Double) As Integer
    Declare Function rsesci_SetServicePulseGenerator Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal pulseGenerator As Integer, ByVal pulseRate As Double) As Integer
    Declare Function rsesci_GetServicePulseGenerator Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByRef pulseGenerator As Integer, ByRef pulseRate As Double) As Integer
    Declare Function rsesci_FirmwareUpdate Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal path As String) As Integer
    Declare Function rsesci_DataSetSave Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal x_fileName As String, ByVal comment As String) As Integer
    Declare Function rsesci_DataSetRecall Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal x_fileName As String) As Integer
    Declare Function rsesci_DataSetRecallAuto Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal x_fileName As String) As Integer
    Declare Function rsesci_DataSetItems Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal dataSetItems As Int32, ByVal selectedItem As Integer) As Integer
    Declare Function rsesci_DataSetCatalog Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal directory As String, ByVal catalog As String, ByVal bufferSize As Int32) As Integer
    Declare Function rsesci_DataSetClear Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal clear As Int32, ByVal path As String) As Integer
    Declare Function rsesci_FileManager Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal operation_to_bePerformed As Int32, ByVal source As String, ByVal destination As String) As Integer
    Declare Function rsesci_readToFile Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal source As String, ByVal destination As String) As Integer
    Declare Function rsesci_writeFromFile Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal source As String, ByVal destination As String) As Integer
    Declare Function rsesci_StoreTraceData Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal trace As Int32, ByVal x_fileName As String) As Integer
    Declare Function rsesci_StoreFinalMeasurementData Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal x_fileName As String) As Integer
    Declare Function rsesci_SetDecimalPointNotation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal decimalSeparator As Int32) As Integer
    Declare Function rsesci_GetDecimalPointNotation Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef decimalSeparator As Int32) As Integer
    Declare Function rsesci_SelectPrinter Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal deviceNumber As Int32, ByVal printerName As String) As Integer
    Declare Function rsesci_QueryPrinterList Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal printerList As String) As Integer
    Declare Function rsesci_AbortHardcopy Lib "rsesci_32.dll" (ByVal instrSession As Integer) As Integer
    Declare Function rsesci_InitiateHardcopy Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal deviceNumber As Int32) As Integer
    Declare Function rsesci_HardcopyDeviceSetup Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal deviceNumber As Int32, ByVal destination As Int32, ByVal dataFormat As Int32, ByVal pageOrientation As Int32, ByVal x_fileName As String) As Integer
    Declare Function rsesci_HardcopyComment Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal comment As String) As Integer
    Declare Function rsesci_HardcopyItems Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal window As Int32, ByVal hardcopyItems As Int32) As Integer
    Declare Function rsesci_HardcopyColor Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal x_color As Integer) As Integer
    Declare Function rsesci_HardcopyUserDefinedColors Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal colorMap As Int32, ByVal predefinedColors As Int32, ByVal tint As Double, ByVal saturation As Double, ByVal brightness As Double) As Integer
    Declare Function rsesci_HardcopyDefaultColors Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal defaultColors As Int32) As Integer
    Declare Function rsesci_errorCheckState Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal stateChecking As Integer) As Integer
    Declare Function rsesci_setStatusRegister Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal registerOperation As Int32, ByVal questionableRegister As Int32, ByVal x_enable As Int32, ByVal PTransition As Int32, ByVal NTransition As Int32) As Integer
    Declare Function rsesci_getStatusRegister Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal statusRegistersQuery As Int32, ByRef registerValue As Int32) As Integer
    Declare Function rsesci_writeInstrData Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal writeBuffer As String) As Integer
    Declare Function rsesci_readInstrData Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal numberBytesToRead As Int32, ByVal readBuffer As String, ByRef numBytesRead As Int32) As Integer
    Declare Function rsesci_reset Lib "rsesci_32.dll" (ByVal instrSession As Integer) As Integer
    Declare Function rsesci_self_test Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef selfTestResult As Int16, ByVal selfTestMessage As String) As Integer
    Declare Function rsesci_error_query Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByRef errorCode As Int32, ByVal errorMessage As String) As Integer
    Declare Function rsesci_error_message Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal statusCode As Integer, ByVal message As String) As Integer
    Declare Function rsesci_revision_query Lib "rsesci_32.dll" (ByVal instrSession As Integer, ByVal instrumentDriverRevision As String, ByVal firmwareRevision As String) As Integer
    Declare Function rsesci_close Lib "rsesci_32.dll" (ByVal instrSession As Integer) As Integer

    '***************************************************************************
    '=== END INCLUDE FILE ======================================================
    '***************************************************************************

End Module